@@ -3,6 +3,7 @@ import pip
 import shutil
 import requests
 import zipfile
+import re
 
 def ask(text):
     r = ''
@@ -90,3 +91,28 @@ def zipdir(target, path):
                 ziph.write(os.path.join(root, file), os.path.join(relpath, os.path.basename(file)), compress_type=zipfile.ZIP_DEFLATED)
             print('')
         ziph.close()
+
+
+class ValidationError(Exception):
+    pass
+
+def checkout(text):
+    r = re.findall(r'^\d+', text)
+    if len(r) > 0:
+        raise ValidationError('Application name can`t starts with leading number')
+    
+    r = re.findall(r'^^\W', text)
+    if len(r) > 0:
+        raise ValidationError('Application name must starts with a letter')
+
+    r = re.findall(r'\s+', text)
+    if len(r) > 0:
+        raise ValidationError('Application name can`t contain spaces')
+   
+    r = re.findall(r'\W+', text)
+    if len(r) > 0:
+        raise ValidationError('Application name can`t contain these symbols: ('+str(r)+')')
+
+    r = re.findall(r'[аб-я]', text)
+    if len(r) > 0:
+        raise ValidationError('Application name can`t contain cyrilic symbols: ('+str(r)+')')
